# /etc/profile.d/sum.sh

# Ensure the script is sourced, not executed
if [ -n "$ZSH_VERSION" ]; then
  # For zsh
  if [[ "${(%):-%x}" == "$0" ]]; then
    echo "This script should be sourced, not executed."
    return 1
  fi
else
  # For bash
  if [[ "${BASH_SOURCE[0]}" == "${0}" ]]; then
    echo "This script should be sourced, not executed."
    return 1
  fi
fi

# Function to generate SHA-256 hashes for .sh files in a given directory
generate_sha256_hashes() {
  local src_dir="$1"

  # Check if the directory exists
  if [ ! -d "$src_dir" ]; then
    echo "Directory $src_dir does not exist."
    return 1
  fi

  # Use shasum by default, and fallback to sha256sum if available
  local hash_cmd="shasum -a 256"
  if command -v sha256sum >/dev/null 2>&1; then
    hash_cmd="sha256sum"
  fi

  # Loop through all .sh files in the directory
  for file in "$src_dir"/*.sh; do
    # Skip if no .sh files are found
    [ -e "$file" ] || continue

    # Calculate the SHA-256 hash and save it to a .sha256 file
    $hash_cmd "$file" | awk '{ print $1 }' > "$file.sha256"
  done

  echo "SHA-256 hashes have been saved in .sha256 files."
}

